@@ -1,4 +1,26 @@
-/* $Id: calendar-conduit.c,v 1.27 2000/03/12 02:28:11 eskil Exp $ */
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- *//* 
+ * Copyright (C) 1998-2000 Free Software Foundation
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ *
+ * Authors: Eskil Heyn Olsen
+ *
+ */
+
+/* $Id: calendar-conduit.c,v 1.29 2000/12/03 03:26:46 eskil Exp $ */
 
 #include <glib.h>
 #include <gnome.h>
@@ -45,7 +67,7 @@ GnomePilotConduit * conduit_get_gpilot_conduit (guint32);
 void conduit_destroy_gpilot_conduit (GnomePilotConduit*);
 void local_record_from_icalobject(GCalLocalRecord *local,iCalObject *obj); 
 
-#define CONDUIT_VERSION "0.8.12"
+#define CONDUIT_VERSION "0.8.13"
 
 #ifdef G_LOG_DOMAIN
 #undef G_LOG_DOMAIN
@@ -360,15 +382,18 @@ ical_from_remote_record(GnomePilotConduitStandardAbs *conduit,
 
 	if (a.event)
 	{
-		/* turn day-long events into a full day's appointment
-		   FIXME: get settings from gnomecal */
+		char *tmp;
+		/* turn No-Time events into events at 8 o'clock with a ALLDAY: marking */
 		a.begin.tm_sec = 0;
 		a.begin.tm_min = 0;
-		a.begin.tm_hour = 0;
+		a.begin.tm_hour = 8;
 
 		a.end.tm_sec = 0;
-		a.end.tm_min =59;
-		a.end.tm_hour = 23;
+		a.end.tm_min = 0;
+		a.end.tm_hour = 9;
+		tmp = g_strdup_printf ("ALLDAY: %s", obj->summary);
+		g_free (obj->summary);
+		obj->summary = tmp;
 	}
 	
 	obj->dtstart = mktime (&a.begin);
@@ -425,7 +450,7 @@ ical_from_remote_record(GnomePilotConduitStandardAbs *conduit,
 			
 		case repeatMonthlyByDate:
 			obj->recur->type = RECUR_MONTHLY_BY_DAY;
-			obj->recur->u.month_day = a.repeatFrequency;
+			obj->recur->u.month_day = a.begin.tm_mday;
 			break;
 			
 		case repeatWeekly:
@@ -447,8 +472,8 @@ ical_from_remote_record(GnomePilotConduitStandardAbs *conduit,
 		
 		case repeatMonthlyByDay:
 			obj->recur->type = RECUR_MONTHLY_BY_POS;
-			obj->recur->u.month_pos = a.repeatFrequency;
-			obj->recur->weekday = (a.repeatDay / 7);
+			obj->recur->u.month_pos = (a.repeatDay / 7) + 1;
+			obj->recur->weekday = (a.repeatDay % 7);
 			break;
 			
 		case repeatYearly:
@@ -1006,10 +1031,12 @@ transmit (GnomePilotConduitStandardAbs *conduit,
 			local->a->repeatType = repeatWeekly;
 			break;
 		case RECUR_MONTHLY_BY_POS:
-			local->a->repeatType = repeatMonthlyByDate;
+			local->a->repeatType = repeatMonthlyByDay;
+			local->a->repeatDay = (local->ical->recur->u.month_pos - 1) * 7;
+			local->a->repeatDay += local->ical->recur->weekday;
 			break;
 		case RECUR_MONTHLY_BY_DAY:
-			local->a->repeatType = repeatMonthlyByDay;
+			local->a->repeatType = repeatMonthlyByDate;
 			break;
 		case RECUR_YEARLY_BY_MONTH:
 			local->a->repeatType = repeatYearly;
@@ -1240,13 +1267,13 @@ compare (GnomePilotConduitStandardAbs *conduit,
 				return 1; }
 			break;
 		case RECUR_MONTHLY_BY_POS:
-			if (a.repeatType != repeatMonthlyByDate) {
-				LOG("failed a.repeatType == repeatMonthlyByDate");
+			if (a.repeatType != repeatMonthlyByDay) {
+				LOG("failed a.repeatType == repeatMonthlyByDay");
 				return 1; }
 			break;
 		case RECUR_MONTHLY_BY_DAY:
-			if (a.repeatType != repeatMonthlyByDay) {
-				LOG("failed a.repeatType == repeatMonthlyByDay");
+			if (a.repeatType != repeatMonthlyByDate) {
+				LOG("failed a.repeatType == repeatMonthlyByDate");
 				return 1; }
 			break;
 		case RECUR_YEARLY_BY_MONTH:
