@@ -950,8 +950,8 @@ static GtkWidget *
 make_numbered_menu (struct numbered_item *items, int sel)
 {
 	GtkWidget *option_menu, *menu;
-	int i;
-
+	int i, history = 0;
+        
 	option_menu = gtk_option_menu_new ();
 	menu = gtk_menu_new ();
 
@@ -962,10 +962,13 @@ make_numbered_menu (struct numbered_item *items, int sel)
 		gtk_object_set_user_data (GTK_OBJECT (item), &items[i]);
 		gtk_menu_append (GTK_MENU (menu), item);
 		gtk_widget_show (item);
+
+                if (items[i].num == sel)
+                    history = i;
 	}
 
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), sel);
+	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), history);
 
 	return option_menu;
 }
