@@ -336,66 +336,38 @@ time_week_end (time_t t)
 	return mktime (&tm);
 }
 
+/* Returns the start of the day, according to the local time. */
 time_t
 time_day_begin (time_t t)
 {
 	struct tm tm;
-	time_t temp = t - 43200;
-	int dstflag, dstflag2;
-	
-	tm = *localtime(&temp); /* one day */
-	dstflag = tm.tm_isdst;
 
 	tm = *localtime (&t);
-	dstflag2 = tm.tm_isdst;
-
-	if (dstflag < dstflag2)
-		tm.tm_hour = 1;
-	else
-		tm.tm_hour = 0;
-
+	tm.tm_hour = 0;
 	tm.tm_min  = 0;
 	tm.tm_sec  = 0;
-	
-	temp = mktime(&tm);
-	if (dstflag > dstflag2){
-		temp += 3600; 
-	}
+	tm.tm_isdst = -1;
 
-	return temp;
+	return mktime (&tm);
 }
 
+/* Returns the end of the day, according to the local time. */
 time_t
 time_day_end (time_t t)
 {
 	struct tm tm;
-	time_t temp;
-	int dstflag, dstflag2;
-
-	t += 10800;
-	temp = t - 86400;
-
-	tm = *localtime(&temp); /* one day */
-	dstflag = tm.tm_isdst;
 
 	tm = *localtime (&t);
-	dstflag2 = tm.tm_isdst;
-
-	if (dstflag < dstflag2)
-		tm.tm_hour = 23;
-	else {
-		tm.tm_mday++;
-		tm.tm_hour = 0;
-	}
+	tm.tm_mday++;
+	tm.tm_hour = 0;
 	tm.tm_min  = 0;
 	tm.tm_sec  = 0;
-	
-	temp = mktime(&tm);
-	if(dstflag > dstflag2) {
-	}
-	return temp;
+	tm.tm_isdst = -1;
+
+	return mktime (&tm);
 }
 
+
 static char *
 pcat (char *dest, int num, char key)
 {
