@@ -845,10 +845,10 @@ strtoCardRev(char *str)
 		     ss = strtok (NULL, "-"), i++)
 		  switch (i) {
 		   case 0:
-			  rev.tm.tm_year = atoi(ss);
+			  rev.tm.tm_year = atoi(ss) - 1900;
 			  break;
 		   case 1:
-			  rev.tm.tm_mon = atoi(ss);
+			  rev.tm.tm_mon = atoi(ss) - 1;
 			  break;
 		   case 2:
 			  rev.tm.tm_mday = atoi(ss);
@@ -863,9 +863,9 @@ strtoCardRev(char *str)
 		if (strlen(str) >= 8) {             /* short representation */
 			rev.tm.tm_mday = atoi(str + 6);
 			str[6] = 0;
-			rev.tm.tm_mon = atoi(str + 4);
+			rev.tm.tm_mon = atoi(str + 4) - 1;
 			str[4] = 0;
-			rev.tm.tm_year = atoi(str);
+			rev.tm.tm_year = atoi(str) - 1900;
 		} else
 		  g_warning("? < Bad format for Rev property.");
 	}
@@ -1408,6 +1408,27 @@ char *card_bday_str(CardBDay bday)
 	return str;
 }
 
+char *card_rev_str(CardRev rev)
+{
+	char *str;
+        size_t len;
+
+        len = 20;
+
+        if (rev.utc)
+            len += 1;           /* Use 'Z' for zone */
+        
+	str = malloc(len);
+	snprintf(str, 20, "%04d-%02d-%02dT%02d:%02d:%02d",
+                 rev.tm.tm_year+1900, rev.tm.tm_mon+1, rev.tm.tm_mday,
+                 rev.tm.tm_hour, rev.tm.tm_min, rev.tm.tm_sec);
+
+        if (rev.utc)
+            strcpy(str+19, "Z");
+        
+	return str;
+}
+
 char *card_timezn_str(CardTimeZone timezn)
 {
 	char *str;
@@ -1462,6 +1483,15 @@ card_convert_to_vobject(Card *crd)
 		add_CardProperty(vprop, &crd->bday.prop);
 	}
 
+	if (crd->rev.prop.used) {
+		char *date_str;
+		
+		date_str = card_rev_str(crd->rev);
+		vprop = addPropValue(vobj, VCLastRevisedProp, date_str);
+		free(date_str);
+		add_CardProperty(vprop, &crd->rev.prop);
+	}
+
 	if (crd->xtension.l) {
 		GList *node;
 		
