@@ -446,7 +446,7 @@ extern DelAddrList *deladdrlist_create_edit_page (Card *crd, GnomePropertyBox *b
 	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
 	
 	for (i = 0; i < DELADDR_MAX; i++) {
-		label = gtk_label_new(deladdr_label[i]);
+		label = gtk_label_new(_(deladdr_label[i]));
 		gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
 		gtk_table_attach(GTK_TABLE(table), label, 0, 1, i, i + 1,
 				 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 
@@ -468,7 +468,7 @@ extern DelAddrList *deladdrlist_create_edit_page (Card *crd, GnomePropertyBox *b
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, GNOME_PAD_SMALL);
 
 	for (i = 0; i < 6; i++) {
-		p->type[i] = gtk_check_button_new_with_label(deladdr_type_name[i]);
+		p->type[i] = gtk_check_button_new_with_label(_(deladdr_type_name[i]));
 		gtk_signal_connect(GTK_OBJECT(p->type[i]), "toggled",
 				   GTK_SIGNAL_FUNC(deladdrlist_data_changed), p);
 		gtk_box_pack_start(GTK_BOX(vbox), p->type[i], FALSE, FALSE, 0);
