@@ -96,7 +96,7 @@ static void gnomecard_prop_apply(GtkWidget *widget, int page)
 	crd->bday.month      = tm->tm_mon + 1;
 	crd->bday.day        = tm->tm_mday;
 	
-	crd->timezn.sign  = (ce->tzh < 0)? -1: 1;
+	crd->timezn.sign  = (gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(ce->tzh)) < 0)? -1: 1;
 	crd->timezn.hours = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(ce->tzh));
 	crd->timezn.mins  = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(ce->tzm));
 	
@@ -676,7 +676,6 @@ gnomecard_setup_apply(GtkWidget *widget, int page)
     gtk_container_add(GTK_CONTAINER(cardlist_scrollwin), 
 		      GTK_WIDGET(gnomecard_list));
 
-    /* FIXME - see if old sort criteria still exists */
     gnomecard_sort_card_list_by_default();
     gnomecard_rebuild_list();
 
