@@ -556,7 +556,7 @@ GnomeUIInfo editmenu[] = {
 	
 	{GNOME_APP_UI_ITEM, N_("Delete"), N_("Erase card"),
 	 gnomecard_delete_current_card, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE, 0, 0, NULL},
+	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_TRASH, 0, 0, NULL},
 	
 	{GNOME_APP_UI_SEPARATOR},
 	
@@ -666,7 +666,7 @@ GnomeUIInfo toolbar[] = {
 	
 	{GNOME_APP_UI_ITEM, N_("Del"), N_("Delete card"),
 	 gnomecard_delete_current_card, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_CLOSE, 0, 0, NULL},
+	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_TRASH, 0, 0, NULL},
 	
 	{GNOME_APP_UI_SEPARATOR},
 	
