@@ -173,15 +173,47 @@ gnomecardFreeColTitles(GList *col)
 GList *
 gnomecardCreateColValues(Card *crd, GList *cols)
 {
-	gchar  *str;
-	GList  *l, *p;
+	gchar *str;
+	GList *l, *p;
+	GList *phone_list, *email_list;
+	ColumnHeader *hdr;
 	
 	l = NULL;
-	for (p=cols; p; p=p->next) {
-	    str = getValFromColumnHdr(crd, (ColumnHeader *)p->data);
-	    if (!str)
-		str = g_strdup("");
-	    l = g_list_append(l, str);
+	email_list = crd->email.l;
+	phone_list = crd->phone.l;
+	
+	for (p = cols; p; p = p->next) {
+		str = NULL;
+		hdr = (ColumnHeader *) p->data;
+		
+		switch (hdr->coltype) {
+		 case COLTYPE_EMAIL:
+			if (email_list) {
+				str = g_strdup
+				  (((CardEMail *) email_list->data)->data);
+				email_list = email_list->next;
+			}
+			break;
+			
+		 case COLTYPE_PHONE:
+			if (phone_list) {
+				str = g_strdup
+				  (((CardPhone *) phone_list->data)->data);
+				phone_list = phone_list->next;
+			}
+			break;
+			
+		 default:
+			str = getValFromColumnHdr(crd, hdr);
+		}
+		
+		if (!str) {
+			if (hdr->coltype == COLTYPE_CARDNAME)
+			  str = g_strdup (_("No Card Name"));
+			else
+			  str = g_strdup("");
+		}
+		l = g_list_append(l, str);
 	}
 
 	return l;
@@ -399,43 +431,9 @@ drag_data_get (GtkWidget        *widget,
 	char *data = NULL;
 	
 	switch (info){
-	case TARGET_TEXT: {
-		GString *string;
-		GList *l;
-		
-		string = g_string_new ("");
-		g_string_append (string, _("Name: "));
-		g_string_append (string, card->fname.str);
-		g_string_append_c (string, '\n');
-
-		if (card->phone.l){
-			g_string_append (string, _("Phones:\n"));
-			
-			for (l = card->phone.l; l; l = l->next){
-				CardPhone *phone = l->data;
-
-				g_string_append (string, "  ");
-				g_string_append (string, phone->data);
-			}
-			g_string_append_c (string, '\n');
-		}
-		
-		if (card->email.l){
-			g_string_append (string, _("E-mail:\n"));
-			
-			for (l = card->email.l; l; l = l->next){
-				CardEMail *email = l->data;
-
-				g_string_append (string, "  ");
-				g_string_append (string, email->data);
-			}
-			g_string_append_c (string, '\n');
-		}
-		
-		data = g_strdup (string->str);
-		g_string_free (string, TRUE);
-	}
-	break;
+	case TARGET_TEXT: 
+		data = card_to_string (card);
+		break;
 		
 	case TARGET_EMAIL: {
 	        char *txt = "";
@@ -449,7 +447,7 @@ drag_data_get (GtkWidget        *widget,
 		break;
 		
 	case TARGET_VCARD:
-		data = card_to_string (card);
+		data = card_to_vobj_string (card);
 		break;
 	}
 
@@ -490,11 +488,9 @@ gnomecardCreateCardListDisplay(ColumnType *hdrs)
     titles = gnomecardCreateColTitles(cols);
 
     for (l=titles, i=0; l; l=l->next, i++) {
-	g_message("setting col %d title to %s", i, (gchar *)l->data);
 	gtk_clist_set_column_title(cardlist, i, (gchar *)l->data);
 
 	/* need to set widths based on user settings probably */
-	/* gtk_clist_set_column_width( GTK_CLIST(cardlist), i, 100); */
 	gtk_clist_set_column_auto_resize(cardlist, i, TRUE);
     }
     
@@ -567,7 +563,6 @@ gnomecardCreateCardListDisplay(ColumnType *hdrs)
 */
 /* & (GTK_WIDGET(crd_tree)->style->fg[GTK_STATE_NORMAL]);*/
     
-    gtk_widget_set_usize (GTK_WIDGET(cardlist), LIST_WIDTH, LIST_HEIGHT);
     gtk_clist_column_titles_active(cardlist);
     gtk_widget_show(GTK_WIDGET(cardlist));
     
