@@ -29,7 +29,8 @@
 
 /* sort_func gnomecard_sort_criteria; */
 
-gint gnomecard_sort_col=COLTYPE_CARDNAME;
+gint gnomecard_sort_col = COLTYPE_CARDNAME; /* isn't used see SortType in
+                                               gnomecard.c */
 
 static gint gnomecard_cmp_fnames(const void *crd1, const void *crd2);
 static gint gnomecard_cmp_names(const void *crd1, const void *crd2);
@@ -165,6 +166,10 @@ gnomecard_sort_cards(GtkWidget *w, gpointer data)
 	gnomecard_sort_col = sort_col;
 	gnomecard_do_sort_cards(sort_col);
 
+        gnome_config_set_string("/GnomeCard/CardDisplay/SortType",
+                                getColumnTypeNameFromType(sort_col));
+
+        gnome_config_sync();
 }
 
 static gint
