@@ -29,7 +29,7 @@
 
 typedef int (*sort_func) (const void *, const void *);
 
-gint gnomecard_sort_col;
+extern gint gnomecard_sort_col;
 
 void gnomecard_sort_card_list(gint sort_col);
 void gnomecard_sort_card_list_by_default(void);
